# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/beo/case_study/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Beo\\CaseStudy\\": "packages/beo/case_study/src",
            "Beo\\CaseStudy\\Seeders\\": "packages/beo/case_study/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Beo\CaseStudy\Providers\CaseStudyServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'CaseStudy'  => Beo\CaseStudy\Facades\CaseStudy::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Beo\\CaseStudy\\Seeders\\CaseStudyTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Beo\CaseStudy\Providers\CaseStudyServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Beo\CaseStudy\Providers\CaseStudyServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Beo\CaseStudy\Providers\CaseStudyServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/case_study/{modulename}

**User**

    http://path-to-route-folder/user/case_study/{modulename}

**Public**

    http://path-to-route-folder/case_studies


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/case_study/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/case_study/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/case_study/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/case_study/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/case_study/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/case_study/{modulename}/{slug}
    METHOD: GET