<?php

namespace Beo\CaseStudy\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Beo\CaseStudy\Http\Resources\CaseStudyResource;
use Beo\CaseStudy\Http\Resources\CaseStudiesCollection;
use Beo\CaseStudy\Scopes\StudyPublicScope;
use Beo\CaseStudy\Models\Study;

class StudyPublicController extends BaseController
{

    /**
     * Show study's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Study::pushScope(new RequestScope())
            ->pushScope(new StudyPublicScope())
            ->select('studies.*')
            ->paginate($pageLimit)
            ->withQueryString();

        $data = new StudiesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('case_study::study.names'))
            ->view('case_study::public.study.index')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show study.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Study::findBySlug($slug);
        $data = new StudyResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('case_study::study.name'))
            ->view('case_study::public.study.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
