<?php

namespace Beo\CaseStudy\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Beo\CaseStudy\Models\Study;

class StudyPolicy
{

    /**
     * Determine if the given user can view the study.
     *
     * @param UserPolicyInterface $authUser
     * @param Study $study
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Study $study)
    {
        if ($authUser->canDo('case_study.study.view') && $authUser->isAdmin()) {
            return true;
        }

        return $study->user_id == user_id() && $study->user_type == user_type();
    }

    /**
     * Determine if the given user can create a study.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('case_study.study.create');
    }

    /**
     * Determine if the given user can update the given study.
     *
     * @param UserPolicyInterface $authUser
     * @param Study $study
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Study $study)
    {
        if ($authUser->canDo('case_study.study.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $study->user_id == user_id() && $study->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given study.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Study $study)
    {
        return $study->user_id == user_id() && $study->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given study.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Study $study)
    {
        if ($authUser->canDo('case_study.study.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given study.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Study $study)
    {
        if ($authUser->canDo('case_study.study.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
