<?php

namespace Beo\CaseStudy\Providers;

use Illuminate\Support\ServiceProvider;
use Beo\CaseStudy\CaseStudies;

class CaseStudyServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'case_study');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'case_study');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        // $this->registerCommands();

        $this->app->register(\Beo\CaseStudy\Providers\AuthServiceProvider::class);
        $this->app->register(\Beo\CaseStudy\Providers\RouteServiceProvider::class);
        // $this->app->register(\Beo\CaseStudy\Providers\EventServiceProvider::class);
        // $this->app->register(\Beo\CaseStudy\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('beo.case_study', function($app)
        {
            return $this->app->make(CaseStudies::class);
        });
    }



    /**
     * Merges user's and case_study's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'beo.case_study'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/study.php', 'beo.case_study.study'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/category.php', 'beo.case_study.category'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Beo\CaseStudy\Commands\CaseStudy::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['beo.case_study'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('beo/case_study')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/case_study')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/case_study')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
